@@ -22,7 +22,7 @@ class PDFSheet:
         [(x, y, max_num_of_characters_per_line, 'text'),
         (x, y, max_num_of_characters_per_line, 'text'),
         (x, y, max_num_of_characters_per_line, 'text')],
- 
+
         [(x, y, max_num_of_characters_per_line, 'text'),
         (x, y, max_num_of_characters_per_line, 'text'),
         (x, y, max_num_of_characters_per_line, 'text')],
@@ -37,23 +37,16 @@ class PDFSheet:
         for idx, block in enumerate(self.data_list):
             cur_col = (idx / self.rows) % self.cols
             cur_row = idx % self.rows
-            # if cur_col == 0:
-            #     ladj = self.left_adj
-            # else:
-            #     ladj = 0
 
             origin = (self.left_adj + cur_col * self.block_width,
                       (self.rows - cur_row - 1) * self.block_height)
 
             textobject = c.beginText()
             for entry in block:
-                # c.drawString(origin[0] + entry[0] * inch,
-                #              origin[1] + entry[1] * inch,
-                #              entry[3])
                 textobject.setTextOrigin(origin[0] + entry[0] * inch,
                                          origin[1] + entry[1] * inch)
                 # textobject.setFont(self.font, self.font_size)
-                for l in split_with_num (entry[3], entry[2]):  
+                for l in split_with_num (entry[3], entry[2]):
                     textobject.textLine(l)
 
             c.drawText(textobject)
@@ -69,9 +62,15 @@ def split_with_num (s, n):
     >>> [i for i in split_with_num ('123', 1)]
     ['1', '2', '3']
     """
-    while len (s) > n:
-        yield s[:n]
-        s = s[n:]
+    while len(s) > n:
+        pre = s[:n]
+        sP = pre.rfind(' ')
+        if pre[-1] == ' ' or s[n] == ' ' or sP < 0:
+            yield pre
+            s = s[n:]
+        else:
+            yield s[:(sP + 1)]
+            s = s[(sP + 1):]
     yield s
 
 if __name__ == '__main__':
